@@ -3,8 +3,8 @@
 def discover_list_with_tab (p_thelist, p_taboption):
         for v_item in p_thelist:
                 if isinstance (v_item, list):
-                        discover_list_with_tab(v_item,1)
+                        discover_list_with_tab(v_item,p_taboption)
                 else:
                         for p_tab_s in range(p_taboption):
-                                print("\t", end='The movie is ')
+                                print("\t", end='')
                         print (v_item)
